==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ServiceTagDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Service Tag destination for a Service Tag Outbound Rule for the managed network of a machine learning workspace.
 * @property portRanges
 * @property protocol
 * @property serviceTag
 */
public data class ServiceTagDestinationArgs(
    public val portRanges: Output<String>? = null,
    public val protocol: Output<String>? = null,
    public val serviceTag: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs.builder()
            .portRanges(portRanges?.applyValue({ args0 -> args0 }))
            .protocol(protocol?.applyValue({ args0 -> args0 }))
            .serviceTag(serviceTag?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceTagDestinationArgs].
 */
@PulumiTagMarker
public class ServiceTagDestinationArgsBuilder internal constructor() {
    private var portRanges: Output<String>? = null

    private var protocol: Output<String>? = null

    private var serviceTag: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("rxjqtywfoklchjhk")
    public suspend fun portRanges(`value`: Output<String>) {
        this.portRanges = value
    }

    /**
     * @param value
     */
    @JvmName("wfwrvbrckobsdlea")
    public suspend fun protocol(`value`: Output<String>) {
        this.protocol = value
    }

    /**
     * @param value
     */
    @JvmName("quadopqgouwmrjer")
    public suspend fun serviceTag(`value`: Output<String>) {
        this.serviceTag = value
    }

    /**
     * @param value
     */
    @JvmName("dwdjhxbnmwgkctbg")
    public suspend fun portRanges(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.portRanges = mapped
    }

    /**
     * @param value
     */
    @JvmName("mdjxmybxfsyofyvu")
    public suspend fun protocol(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value
     */
    @JvmName("lyegtvqwiexqhyrk")
    public suspend fun serviceTag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTag = mapped
    }

    internal fun build(): ServiceTagDestinationArgs = ServiceTagDestinationArgs(
        portRanges = portRanges,
        protocol = protocol,
        serviceTag = serviceTag,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ServiceTagDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Service Tag destination for a Service Tag Outbound Rule for the managed network of a machine learning workspace.
 * @property portRanges
 * @property protocol
 * @property serviceTag
 */
public data class ServiceTagDestinationArgs(
    public val portRanges: Output<String>? = null,
    public val protocol: Output<String>? = null,
    public val serviceTag: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ServiceTagDestinationArgs.builder()
            .portRanges(portRanges?.applyValue({ args0 -> args0 }))
            .protocol(protocol?.applyValue({ args0 -> args0 }))
            .serviceTag(serviceTag?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceTagDestinationArgs].
 */
@PulumiTagMarker
public class ServiceTagDestinationArgsBuilder internal constructor() {
    private var portRanges: Output<String>? = null

    private var protocol: Output<String>? = null

    private var serviceTag: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("rkshmolisnjcanke")
    public suspend fun portRanges(`value`: Output<String>) {
        this.portRanges = value
    }

    /**
     * @param value
     */
    @JvmName("caxottodihbwxhoq")
    public suspend fun protocol(`value`: Output<String>) {
        this.protocol = value
    }

    /**
     * @param value
     */
    @JvmName("kumrgdxoqysoivyp")
    public suspend fun serviceTag(`value`: Output<String>) {
        this.serviceTag = value
    }

    /**
     * @param value
     */
    @JvmName("lftdsfqeimstpjrx")
    public suspend fun portRanges(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.portRanges = mapped
    }

    /**
     * @param value
     */
    @JvmName("nptadttlyecvyfqw")
    public suspend fun protocol(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value
     */
    @JvmName("jguotvgnkolwaisy")
    public suspend fun serviceTag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTag = mapped
    }

    internal fun build(): ServiceTagDestinationArgs = ServiceTagDestinationArgs(
        portRanges = portRanges,
        protocol = protocol,
        serviceTag = serviceTag,
    )
}
